/*
	Author: Marco Costalba (C) 2005-2006

	Copyright: See COPYING file that comes with this distribution

*/
#ifndef CACHE_H
#define CACHE_H

#include "git.h"

class Cache : public QObject {
Q_OBJECT
public:
	Cache(QObject *par = 0) : QObject(par) {};
	bool save(const QString& workDir, const RevFileMap& rf,
	          const StrVect& dirs, const StrVect& files);
	bool load(const QString& workDir, RevFileMap& rf,
	          StrVect& dirs, StrVect& files);
};

#endif
